==> opensimcreator-0.3.2-src.tar.xz: opensim-creator_0.3.2/src/OpenSimBindings/BasicModelStatePair.cpp <==
#include "BasicModelStatePair.hpp"

#include "src/OpenSimBindings/OpenSimHelpers.hpp"

#include <OpenSim/Simulation/Model/Model.h>
#include <OpenSim/Simulation/SimbodyEngine/Coordinate.h>

#include <memory>
#include <utility>

class osc::BasicModelStatePair::Impl final {
public:

    Impl() :
        m_Model{std::make_unique<OpenSim::Model>()}
    {
        InitializeModel(*m_Model);
        InitializeState(*m_Model);
    }

    Impl(VirtualModelStatePair const& p) :
        Impl{p.getModel(), p.getState()}
    {
        m_FixupScaleFactor = p.getFixupScaleFactor();
    }

    Impl(OpenSim::Model const& m, SimTK::State const& st) :
        m_Model(std::make_unique<OpenSim::Model>(m))
    {
        InitializeModel(*m_Model);
        InitializeState(*m_Model);
        m_Model->updWorkingState() = st;
        m_Model->updWorkingState().invalidateAllCacheAtOrAbove(SimTK::Stage::Instance);
        m_Model->realizeReport(m_Model->updWorkingState());
    }

    Impl(Impl const& o) :
        m_Model{std::make_unique<OpenSim::Model>(*o.m_Model)}
    {
        InitializeModel(*m_Model);
        InitializeState(*m_Model);
        m_Model->updWorkingState() = o.m_Model->getWorkingState();
    }

    std::unique_ptr<Impl> clone()
    {
        return std::make_unique<Impl>(*this);
    }

    OpenSim::Model const& getModel() const
    {
        return *m_Model;
    }

    SimTK::State const& getState() const
    {
        return m_Model->getWorkingState();
    }

    float getFixupScaleFactor() const
    {
        return m_FixupScaleFactor;
    }

    void setFixupScaleFactor(float v)
    {
        m_FixupScaleFactor = std::move(v);
    }

private:
    std::unique_ptr<OpenSim::Model> m_Model;
    float m_FixupScaleFactor = 1.0f;
};


// public API

osc::BasicModelStatePair::BasicModelStatePair() :
    m_Impl{new Impl{}}
{
}

osc::BasicModelStatePair::BasicModelStatePair(VirtualModelStatePair const& p) :
    m_Impl{new Impl{p}}
{
}
osc::BasicModelStatePair::BasicModelStatePair(OpenSim::Model const& model, SimTK::State const& state) :
    m_Impl{new Impl{model, state}}
{
}
osc::BasicModelStatePair::BasicModelStatePair(BasicModelStatePair const&) = default;
osc::BasicModelStatePair::BasicModelStatePair(BasicModelStatePair&&) noexcept = default;
osc::BasicModelStatePair& osc::BasicModelStatePair::operator=(BasicModelStatePair const&) = default;
osc::BasicModelStatePair& osc::BasicModelStatePair::operator=(BasicModelStatePair&&) noexcept = default;
osc::BasicModelStatePair::~BasicModelStatePair() noexcept = default;

OpenSim::Model const& osc::BasicModelStatePair::getModel() const
{
    return m_Impl->getModel();
}

SimTK::State const& osc::BasicModelStatePair::getState() const
{
    return m_Impl->getState();
}

float osc::BasicModelStatePair::getFixupScaleFactor() const
{
    return m_Impl->getFixupScaleFactor();
}

void osc::BasicModelStatePair::setFixupScaleFactor(float v)
{
    m_Impl->setFixupScaleFactor(std::move(v));
}

==> opensimcreator-0.4.0-src.tar.xz: opensim-creator_0.4.0/src/OpenSimBindings/BasicModelStatePair.cpp <==
#include "BasicModelStatePair.hpp"

#include "src/OpenSimBindings/OpenSimHelpers.hpp"

#include <OpenSim/Simulation/Model/Model.h>
#include <OpenSim/Simulation/SimbodyEngine/Coordinate.h>

#include <memory>
#include <utility>

class osc::BasicModelStatePair::Impl final {
public:

    Impl() :
        m_Model{std::make_unique<OpenSim::Model>()}
    {
        InitializeModel(*m_Model);
        InitializeState(*m_Model);
    }

    Impl(VirtualModelStatePair const& p) :
        Impl{p.getModel(), p.getState()}
    {
        m_FixupScaleFactor = p.getFixupScaleFactor();
    }

    Impl(OpenSim::Model const& m, SimTK::State const& st) :
        m_Model(std::make_unique<OpenSim::Model>(m))
    {
        InitializeModel(*m_Model);
        InitializeState(*m_Model);
        m_Model->updWorkingState() = st;
        m_Model->updWorkingState().invalidateAllCacheAtOrAbove(SimTK::Stage::Instance);
        m_Model->realizeReport(m_Model->updWorkingState());
    }

    Impl(Impl const& o) :
        m_Model{std::make_unique<OpenSim::Model>(*o.m_Model)}
    {
        InitializeModel(*m_Model);
        InitializeState(*m_Model);
        m_Model->updWorkingState() = o.m_Model->getWorkingState();
    }

    std::unique_ptr<Impl> clone()
    {
        return std::make_unique<Impl>(*this);
    }

    OpenSim::Model const& getModel() const
    {
        return *m_Model;
    }

    SimTK::State const& getState() const
    {
        return m_Model->getWorkingState();
    }

    float getFixupScaleFactor() const
    {
        return m_FixupScaleFactor;
    }

    void setFixupScaleFactor(float v)
    {
        m_FixupScaleFactor = std::move(v);
    }

private:
    std::unique_ptr<OpenSim::Model> m_Model;
    float m_FixupScaleFactor = 1.0f;
};


// public API

osc::BasicModelStatePair::BasicModelStatePair() :
    m_Impl{new Impl{}}
{
}

osc::BasicModelStatePair::BasicModelStatePair(VirtualModelStatePair const& p) :
    m_Impl{new Impl{p}}
{
}
osc::BasicModelStatePair::BasicModelStatePair(OpenSim::Model const& model, SimTK::State const& state) :
    m_Impl{new Impl{model, state}}
{
}
osc::BasicModelStatePair::BasicModelStatePair(BasicModelStatePair const&) = default;
osc::BasicModelStatePair::BasicModelStatePair(BasicModelStatePair&&) noexcept = default;
osc::BasicModelStatePair& osc::BasicModelStatePair::operator=(BasicModelStatePair const&) = default;
osc::BasicModelStatePair& osc::BasicModelStatePair::operator=(BasicModelStatePair&&) noexcept = default;
osc::BasicModelStatePair::~BasicModelStatePair() noexcept = default;

OpenSim::Model const& osc::BasicModelStatePair::implGetModel() const
{
    return m_Impl->getModel();
}

SimTK::State const& osc::BasicModelStatePair::implGetState() const
{
    return m_Impl->getState();
}

float osc::BasicModelStatePair::implGetFixupScaleFactor() const
{
    return m_Impl->getFixupScaleFactor();
}

void osc::BasicModelStatePair::implSetFixupScaleFactor(float v)
{
    m_Impl->setFixupScaleFactor(std::move(v));
}
